"use strict";

var _interopRequireDefault2 = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.verifyRelease = verifyRelease;
exports.validateCommits = validateCommits;

var config = _interopRequireWildcard(require("@commitlint/config-conventional"));

var commitlint = _interopRequireWildcard(require("@commitlint/core"));

var _error = _interopRequireDefault2(require("@semantic-release/error"));

var _interopRequireDefault = _interopRequireDefault2(require("@babel/runtime/helpers/interopRequireDefault"));

const format = (0, _interopRequireDefault.default)(commitlint.format).default,
      lint = (0, _interopRequireDefault.default)(commitlint.lint).default,
      load = (0, _interopRequireDefault.default)(commitlint.load).default;

async function verifyRelease(repoData, options) {
  return validateCommits(options);
}

async function validateCommits({
  commits,
  logger
}) {
  const opts = await load(config);
  const skipCommits = (process.env.SEMANTIC_COMMITLINT_SKIP || '').split(',').filter(sha => sha);
  await Promise.all(commits.map(commit => {
    const skipCommit = skipCommits.some(commitPrefix => commit.commit.long.startsWith(commitPrefix));
    return skipCommit ? null : validateCommit(commit, opts, logger);
  }));
  logger.log('All commits validated with commitlint');
}

async function validateCommit(commitMeta, opts, logger) {
  const report = await lint(`${commitMeta.message}`, opts.rules, opts.parserPreset ? {
    parserOpts: opts.parserPreset.parserOpts
  } : {});

  if (!report.valid) {
    const detail = commitMeta.commit.short ? ` ${commitMeta.commit.short}` : '';
    logger.error(`😞   Errors found with commit${detail}`);
    logger.error(`💬   ${commitMeta.message}`);
    const formatted = format({
      results: [report]
    });
    logger.log(formatted);
    throw new _error.default(`The commit message is not formatted correctly`, 'EINVALIDCOMMIT');
  }
}